==> keycloak-model-map-18.0.0-sources.jar: org/keycloak/models/map/clientscope/MapClientScopeEntityFieldDelegate.java <==
package org.keycloak.models.map.clientscope;
public class MapClientScopeEntityFieldDelegate extends org.keycloak.models.map.clientscope.MapClientScopeEntity.AbstractClientScopeEntity implements org.keycloak.models.map.clientscope.MapClientScopeEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.clientscope.MapClientScopeEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.clientscope.MapClientScopeEntity> entityFieldDelegate;
    public MapClientScopeEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.clientscope.MapClientScopeEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.clientscope.MapClientScopeEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @SuppressWarnings("unchecked") @Override public java.util.Map<String,java.util.List<String>> getAttributes() {
        return (java.util.Map<String,java.util.List<String>>) entityFieldDelegate.get(org.keycloak.models.map.clientscope.MapClientScopeEntityFields.ATTRIBUTES);
    }
    @SuppressWarnings("unchecked") @Override public void setAttributes(java.util.Map<String,java.util.List<String>> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.clientscope.MapClientScopeEntityFields.ATTRIBUTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.List<String> getAttribute(String p0) {
        return (java.util.List<String>) entityFieldDelegate.mapGet(org.keycloak.models.map.clientscope.MapClientScopeEntityFields.ATTRIBUTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public void setAttribute(String p0, java.util.List<String> p1) {
        entityFieldDelegate.mapPut(org.keycloak.models.map.clientscope.MapClientScopeEntityFields.ATTRIBUTES, p0, p1);
    }
    @SuppressWarnings("unchecked") @Override public void removeAttribute(String p0) {
        entityFieldDelegate.mapRemove(org.keycloak.models.map.clientscope.MapClientScopeEntityFields.ATTRIBUTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.clientscope.MapClientScopeEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.clientscope.MapClientScopeEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getName() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.clientscope.MapClientScopeEntityFields.NAME);
    }
    @SuppressWarnings("unchecked") @Override public String getDescription() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.clientscope.MapClientScopeEntityFields.DESCRIPTION);
    }
    @SuppressWarnings("unchecked") @Override public String getProtocol() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.clientscope.MapClientScopeEntityFields.PROTOCOL);
    }
    @SuppressWarnings("unchecked") @Override public String getRealmId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.clientscope.MapClientScopeEntityFields.REALM_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setName(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.clientscope.MapClientScopeEntityFields.NAME, p0);
    }
    @SuppressWarnings("unchecked") @Override public void setDescription(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.clientscope.MapClientScopeEntityFields.DESCRIPTION, p0);
    }
    @SuppressWarnings("unchecked") @Override public void setProtocol(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.clientscope.MapClientScopeEntityFields.PROTOCOL, p0);
    }
    @SuppressWarnings("unchecked") @Override public void setRealmId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.clientscope.MapClientScopeEntityFields.REALM_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Set<org.keycloak.models.map.client.MapProtocolMapperEntity> getProtocolMappers() {
        return (java.util.Set<org.keycloak.models.map.client.MapProtocolMapperEntity>) entityFieldDelegate.get(org.keycloak.models.map.clientscope.MapClientScopeEntityFields.PROTOCOL_MAPPERS);
    }
    @SuppressWarnings("unchecked") @Override public void addProtocolMapper(org.keycloak.models.map.client.MapProtocolMapperEntity p0) {
        entityFieldDelegate.collectionAdd(org.keycloak.models.map.clientscope.MapClientScopeEntityFields.PROTOCOL_MAPPERS, p0);
    }
    @SuppressWarnings("unchecked") @Override public void addScopeMapping(String p0) {
        entityFieldDelegate.collectionAdd(org.keycloak.models.map.clientscope.MapClientScopeEntityFields.SCOPE_MAPPINGS, p0);
    }
    @SuppressWarnings("unchecked") @Override public void removeScopeMapping(String p0) {
        entityFieldDelegate.collectionRemove(org.keycloak.models.map.clientscope.MapClientScopeEntityFields.SCOPE_MAPPINGS, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Collection<String> getScopeMappings() {
        return (java.util.Collection<String>) entityFieldDelegate.get(org.keycloak.models.map.clientscope.MapClientScopeEntityFields.SCOPE_MAPPINGS);
    }
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/clientscope/MapClientScopeEntityFieldDelegate.java <==
package org.keycloak.models.map.clientscope;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapClientScopeEntityFieldDelegate extends org.keycloak.models.map.clientscope.MapClientScopeEntity.AbstractClientScopeEntity implements org.keycloak.models.map.clientscope.MapClientScopeEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.clientscope.MapClientScopeEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.clientscope.MapClientScopeEntity> entityFieldDelegate;
    public MapClientScopeEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.clientscope.MapClientScopeEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.clientscope.MapClientScopeEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @Override public boolean isUpdated() {
        return entityFieldDelegate.isUpdated();
    }
    @Override public void clearUpdatedFlag() {
        entityFieldDelegate.clearUpdatedFlag();
    }
    @SuppressWarnings("unchecked") @Override public java.util.Map<String,java.util.List<String>> getAttributes() {
        return (java.util.Map<String,java.util.List<String>>) entityFieldDelegate.get(org.keycloak.models.map.clientscope.MapClientScopeEntityFields.ATTRIBUTES);
    }
    @SuppressWarnings("unchecked") @Override public void setAttributes(java.util.Map<String,java.util.List<String>> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.clientscope.MapClientScopeEntityFields.ATTRIBUTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.List<String> getAttribute(String p0) {
        return (java.util.List<String>) entityFieldDelegate.mapGet(org.keycloak.models.map.clientscope.MapClientScopeEntityFields.ATTRIBUTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public void setAttribute(String p0, java.util.List<String> p1) {
        entityFieldDelegate.mapPut(org.keycloak.models.map.clientscope.MapClientScopeEntityFields.ATTRIBUTES, p0, p1);
    }
    @SuppressWarnings("unchecked") @Override public void removeAttribute(String p0) {
        entityFieldDelegate.mapRemove(org.keycloak.models.map.clientscope.MapClientScopeEntityFields.ATTRIBUTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.clientscope.MapClientScopeEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.clientscope.MapClientScopeEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getName() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.clientscope.MapClientScopeEntityFields.NAME);
    }
    @SuppressWarnings("unchecked") @Override public String getDescription() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.clientscope.MapClientScopeEntityFields.DESCRIPTION);
    }
    @SuppressWarnings("unchecked") @Override public String getProtocol() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.clientscope.MapClientScopeEntityFields.PROTOCOL);
    }
    @SuppressWarnings("unchecked") @Override public String getRealmId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.clientscope.MapClientScopeEntityFields.REALM_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setName(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.clientscope.MapClientScopeEntityFields.NAME, p0);
    }
    @SuppressWarnings("unchecked") @Override public void setDescription(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.clientscope.MapClientScopeEntityFields.DESCRIPTION, p0);
    }
    @SuppressWarnings("unchecked") @Override public void setProtocol(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.clientscope.MapClientScopeEntityFields.PROTOCOL, p0);
    }
    @SuppressWarnings("unchecked") @Override public void setRealmId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.clientscope.MapClientScopeEntityFields.REALM_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Optional<org.keycloak.models.map.client.MapProtocolMapperEntity> getProtocolMapper(String p0) {
        return (java.util.Optional<org.keycloak.models.map.client.MapProtocolMapperEntity>) entityFieldDelegate.mapGet(org.keycloak.models.map.clientscope.MapClientScopeEntityFields.PROTOCOL_MAPPERS, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Set<org.keycloak.models.map.client.MapProtocolMapperEntity> getProtocolMappers() {
        return (java.util.Set<org.keycloak.models.map.client.MapProtocolMapperEntity>) entityFieldDelegate.get(org.keycloak.models.map.clientscope.MapClientScopeEntityFields.PROTOCOL_MAPPERS);
    }
    @SuppressWarnings("unchecked") @Override public void addProtocolMapper(org.keycloak.models.map.client.MapProtocolMapperEntity p0) {
        entityFieldDelegate.collectionAdd(org.keycloak.models.map.clientscope.MapClientScopeEntityFields.PROTOCOL_MAPPERS, p0);
    }
    @SuppressWarnings("unchecked") @Override public void removeProtocolMapper(String p0) {
        entityFieldDelegate.mapRemove(org.keycloak.models.map.clientscope.MapClientScopeEntityFields.PROTOCOL_MAPPERS, p0);
    }
    @SuppressWarnings("unchecked") @Override public void addScopeMapping(String p0) {
        entityFieldDelegate.collectionAdd(org.keycloak.models.map.clientscope.MapClientScopeEntityFields.SCOPE_MAPPINGS, p0);
    }
    @SuppressWarnings("unchecked") @Override public void removeScopeMapping(String p0) {
        entityFieldDelegate.collectionRemove(org.keycloak.models.map.clientscope.MapClientScopeEntityFields.SCOPE_MAPPINGS, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Collection<String> getScopeMappings() {
        return (java.util.Collection<String>) entityFieldDelegate.get(org.keycloak.models.map.clientscope.MapClientScopeEntityFields.SCOPE_MAPPINGS);
    }
}
